about summary refs log tree commit diff
path: root/support/resolv_test.c
diff options
context:
space:
mode:
authorPaul Pluzhnikov <ppluzhnikov@google.com>2023-05-20 13:37:47 +0000
committerPaul Pluzhnikov <ppluzhnikov@google.com>2023-06-02 01:39:48 +0000
commit7f0d9e61f40c669fca3cfd1e342fa8236c7220b7 (patch)
treee02ce0ba813f2cb4f20643988ec030292784cab6 /support/resolv_test.c
parent5013f6fc6c44160e8ec6bcd34ba676e85d9d6ab6 (diff)
downloadglibc-7f0d9e61f40c669fca3cfd1e342fa8236c7220b7.tar.gz
glibc-7f0d9e61f40c669fca3cfd1e342fa8236c7220b7.tar.xz
glibc-7f0d9e61f40c669fca3cfd1e342fa8236c7220b7.zip
Fix all the remaining misspellings -- BZ 25337
Diffstat (limited to 'support/resolv_test.c')
-rw-r--r--support/resolv_test.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/support/resolv_test.c b/support/resolv_test.c
index fd1f5e78bb..c5694631f2 100644
--- a/support/resolv_test.c
+++ b/support/resolv_test.c
@@ -91,7 +91,7 @@ ascii_tolower (unsigned char ch)
 }
 
 /* Compare both names, for use with tsearch.  The order is arbitrary,
-   but the comparison is case-insenstive.  */
+   but the comparison is case-insensitive.  */
 static int
 compare_compressed_name (const void *left, const void *right)
 {
@@ -119,7 +119,7 @@ compare_compressed_name (const void *left, const void *right)
       if (lenleft == 0)
         /* End of name reached without spotting a difference.  */
         return 0;
       /* Compare the label in a case-insenstive manner.  */
       const unsigned char *endnameleft = nameleft + lenleft;
       while (nameleft < endnameleft)
         {
@@ -525,7 +525,7 @@ parse_query (struct query_info *info,
       _Static_assert (sizeof (rr) == 11, "EDNS record size");
 
       if (remaining < 4 + sizeof (rr))
-        FAIL_EXIT1 ("mailformed DNS query: no room for EDNS record");
+        FAIL_EXIT1 ("malformed DNS query: no room for EDNS record");
       memcpy (&rr, buffer + 12 + ret + 4, sizeof (rr));
       if (rr.root != 0)
         FAIL_EXIT1 ("malformed DNS query: invalid OPT RNAME: %d\n", rr.root);
@@ -843,7 +843,7 @@ writev_fully (int fd, struct iovec *buffers, size_t count)
           --count;
           continue;
         }
-      /* Try to rewrite the remaing buffers.  */
+      /* Try to rewrite the remaining buffers.  */
       ssize_t ret = writev (fd, buffers, count);
       if (ret < 0)
         FAIL_EXIT1 ("writev: %m");
@@ -969,7 +969,7 @@ server_thread_tcp (struct resolv_test *obj, int server_index)
 {
   while (true)
     {
-      /* Get the client conenction.  */
+      /* Get the client connection.  */
       int client_socket = xaccept
         (obj->servers[server_index].socket_tcp, NULL, NULL);
@@ -119,7 +119,7 @@ compare_compressed_name (const void *left, const void *right)
         /* End of name reached without spotting a difference.  */
         return 0;
-      /* Compare the label in a case-insenstive manner.  */
+      /* Compare the label in a case-insensitive manner.  */
       const unsigned char *endnameleft = nameleft + lenleft;
       while (nameleft < endnameleft)